# pythologist-image-utilities

For function details please [Read The Docs](https://jason-weirather.github.io/pythologist-image-utilities/)

Functions for working with image data in python

### About

This set of functions are used in the construction of pythologist-reader intermediate storage format, and in the analysis of image data .. finding neighbors .. or the generation of images.  